# Copyright (c) Alibaba, Inc. and its affiliates.
import os

CACHE_DIR = os.path.expanduser('~/.cache/easycv/')

MAX_READ_IMAGE_TRY_TIMES = 10
